Flask-PyCasbin
===========

Flask-PyCasbin is an extension for [Flask](http://flask.pocoo.org/) that integrates with [PyCasbin](https://pypi.org/project/casbin/).

Compatibility
-------------

For now Python 3.5+.

Installation
------------

With pip:
```
$ pip install flask-pycasbin
```